package com.phm.manage.mapper;

import com.phm.manage.domain.AnalyzeCourseLog;

import java.util.List;

/**
 * 分析过程日志Mapper接口
 *
 * @author phm
 * @date 2023-08-31
 */
public interface AnalyzeCourseLogMapper {
    /**
     * 查询分析过程日志
     *
     * @param id 分析过程日志主键
     * @return 分析过程日志
     */
    public AnalyzeCourseLog selectAnalyzeCourseLogById(Long id);

    /**
     * 查询分析过程日志列表
     *
     * @param analyzeCourseLog 分析过程日志
     * @return 分析过程日志集合
     */
    public List<AnalyzeCourseLog> selectAnalyzeCourseLogList(AnalyzeCourseLog analyzeCourseLog);

    /**
     * 新增分析过程日志
     *
     * @param analyzeCourseLog 分析过程日志
     * @return 结果
     */
    public int insertAnalyzeCourseLog(AnalyzeCourseLog analyzeCourseLog);

    /**
     * 修改分析过程日志
     *
     * @param analyzeCourseLog 分析过程日志
     * @return 结果
     */
    public int updateAnalyzeCourseLog(AnalyzeCourseLog analyzeCourseLog);

    /**
     * 删除分析过程日志
     *
     * @param id 分析过程日志主键
     * @return 结果
     */
    public int deleteAnalyzeCourseLogById(Long id);

    /**
     * 批量删除分析过程日志
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAnalyzeCourseLogByIds(Long[] ids);
}
